@@ -59,11 +59,11 @@ public:
   Macro* macroFromIndex( const QModelIndex& index ) const;
 
   // reimplementations from QAbstractTableModel
-  virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const;
-  virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-  virtual QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
-  virtual QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const;
-  virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const;
+  int columnCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
+  QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
+  QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
+  QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
+  int rowCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
 };
 
 /**
