@@ -623,6 +623,20 @@ bool AbstractLineImp::isPropertyDefinedOnOrThroughThisImp( int which ) const
 {
   int pnum = 0;
 
+  if ( which < Parent::numberOfProperties() )
+    return Parent::isPropertyDefinedOnOrThroughThisImp( which );
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return false;
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return false;
+  else assert( false );
+  return false;
+}
+
+bool SegmentImp::isPropertyDefinedOnOrThroughThisImp( int which ) const
+{
+  int pnum = 0;
+
   if ( which < Parent::numberOfProperties() )
     return Parent::isPropertyDefinedOnOrThroughThisImp( which );
   else if ( which == Parent::numberOfProperties() + pnum++ )
@@ -633,6 +647,24 @@ bool AbstractLineImp::isPropertyDefinedOnOrThroughThisImp( int which ) const
     return true;
   else if ( which == Parent::numberOfProperties() + pnum++ )
     return true;
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return true;
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return true;
+  else assert( false );
+  return false;
+}
+
+bool RayImp::isPropertyDefinedOnOrThroughThisImp( int which ) const
+{
+  int pnum = 0;
+
+  if ( which < Parent::numberOfProperties() )
+    return Parent::isPropertyDefinedOnOrThroughThisImp( which );
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return true;
+  else if ( which == Parent::numberOfProperties() + pnum++ )
+    return true;
   else assert( false );
   return false;
 }
